@@ -4,6 +4,8 @@
 # 20181214
 #
 
+set -e
+
 [ "$(id -u)" = "0" ] || SUDO="sudo"
 
 echo "##############################################"
@@ -25,6 +27,8 @@ fi
 BUILDDEPENDS="$(LANG=C dpkg-checkbuilddeps 2>&1 | sed -e 's|dpkg-checkbuilddeps: error: Unmet build dependencies: ||' -e 's|[(][^)]*[)]||g')"
 if [ -n "$BUILDDEPENDS" ]; then
   $SUDO apt update -y
+  $SUDO apt install dpkg-dev
+  $SUDO dpkg --add-architecture i386
   $SUDO apt install -y $BUILDDEPENDS kmod
 else
   echo "Nothing to do."
